@@ -2,13 +2,17 @@ package POE::Component::IRC::Plugin::NickServID;
 
 use strict;
 use warnings;
+use Carp;
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Common qw( u_irc );
 
 our $VERSION = '1.2';
 
 sub new {
-    my ($package, %self) = @_;
+    my ($package) = shift;
+    croak "$package requires an even number of arguments" if @_ & 1;
+    my %self = @_;
+    
     die "$package requires a Password" if !defined $self{Password};
     return bless \%self, $package;
 }
@@ -46,7 +50,7 @@ __END__
 =head1 NAME
 
 POE::Component::IRC::Plugin::NickServID - A PoCo-IRC plugin
-which identifies with FreeNode's NickServ when needed.
+which identifies with FreeNode's NickServ when needed
 
 =head1 SYNOPSIS
 
